# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Trail(pulumi.CustomResource):
    event_rw: pulumi.Output[str]
    """
    Indicates whether the event is a read or a write event. Valid values: Read, Write, and All. Default value: Write.
    """
    name: pulumi.Output[str]
    """
    The name of the trail to be created, which must be unique for an account.
    """
    oss_bucket_name: pulumi.Output[str]
    """
    The OSS bucket to which the trail delivers logs. Ensure that this is an existing OSS bucket.
    """
    oss_key_prefix: pulumi.Output[str]
    """
    The prefix of the specified OSS bucket name. This parameter can be left empty.
    """
    role_name: pulumi.Output[str]
    """
    The RAM role in ActionTrail permitted by the user.
    """
    sls_project_arn: pulumi.Output[str]
    """
    The unique ARN of the Log Service project.
    """
    sls_write_role_arn: pulumi.Output[str]
    """
    The unique ARN of the Log Service role.
    """
    def __init__(__self__, resource_name, opts=None, event_rw=None, name=None, oss_bucket_name=None, oss_key_prefix=None, role_name=None, sls_project_arn=None, sls_write_role_arn=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a new resource to manage [Action Trail](https://www.alibabacloud.com/help/doc-detail/28804.htm).
        
        > **NOTE:** Available in 1.35.0+
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] event_rw: Indicates whether the event is a read or a write event. Valid values: Read, Write, and All. Default value: Write.
        :param pulumi.Input[str] name: The name of the trail to be created, which must be unique for an account.
        :param pulumi.Input[str] oss_bucket_name: The OSS bucket to which the trail delivers logs. Ensure that this is an existing OSS bucket.
        :param pulumi.Input[str] oss_key_prefix: The prefix of the specified OSS bucket name. This parameter can be left empty.
        :param pulumi.Input[str] role_name: The RAM role in ActionTrail permitted by the user.
        :param pulumi.Input[str] sls_project_arn: The unique ARN of the Log Service project.
        :param pulumi.Input[str] sls_write_role_arn: The unique ARN of the Log Service role.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/r/actiontrail.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['event_rw'] = event_rw
            __props__['name'] = name
            if oss_bucket_name is None:
                raise TypeError("Missing required property 'oss_bucket_name'")
            __props__['oss_bucket_name'] = oss_bucket_name
            __props__['oss_key_prefix'] = oss_key_prefix
            if role_name is None:
                raise TypeError("Missing required property 'role_name'")
            __props__['role_name'] = role_name
            __props__['sls_project_arn'] = sls_project_arn
            __props__['sls_write_role_arn'] = sls_write_role_arn
        super(Trail, __self__).__init__(
            'alicloud:actiontrail/trail:Trail',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, event_rw=None, name=None, oss_bucket_name=None, oss_key_prefix=None, role_name=None, sls_project_arn=None, sls_write_role_arn=None):
        """
        Get an existing Trail resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] event_rw: Indicates whether the event is a read or a write event. Valid values: Read, Write, and All. Default value: Write.
        :param pulumi.Input[str] name: The name of the trail to be created, which must be unique for an account.
        :param pulumi.Input[str] oss_bucket_name: The OSS bucket to which the trail delivers logs. Ensure that this is an existing OSS bucket.
        :param pulumi.Input[str] oss_key_prefix: The prefix of the specified OSS bucket name. This parameter can be left empty.
        :param pulumi.Input[str] role_name: The RAM role in ActionTrail permitted by the user.
        :param pulumi.Input[str] sls_project_arn: The unique ARN of the Log Service project.
        :param pulumi.Input[str] sls_write_role_arn: The unique ARN of the Log Service role.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/r/actiontrail.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["event_rw"] = event_rw
        __props__["name"] = name
        __props__["oss_bucket_name"] = oss_bucket_name
        __props__["oss_key_prefix"] = oss_key_prefix
        __props__["role_name"] = role_name
        __props__["sls_project_arn"] = sls_project_arn
        __props__["sls_write_role_arn"] = sls_write_role_arn
        return Trail(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

