# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class BandwidthPackage(pulumi.CustomResource):
    bandwidth: pulumi.Output[float]
    """
    The bandwidth in Mbps of the bandwidth package. Cannot be less than 2Mbps.
    """
    charge_type: pulumi.Output[str]
    """
    The billing method. Valid value: PostPaid | PrePaid. Default to PostPaid. If set to PrePaid, the bandwidth package can't be deleted before expired time.
    """
    description: pulumi.Output[str]
    """
    The description of the bandwidth package. Default to null.
    """
    expired_time: pulumi.Output[str]
    """
    The time of the bandwidth package to expire.
    """
    geographic_region_ids: pulumi.Output[list]
    """
    List of the two areas to connect. Valid value: China | North-America | Asia-Pacific | Europe | Middle-East.
    """
    name: pulumi.Output[str]
    """
    The name of the bandwidth package. Defaults to null.
    """
    period: pulumi.Output[float]
    """
    The purchase period in month. Valid value: 1, 2, 3, 6, 12. Default to 1.
    """
    status: pulumi.Output[str]
    """
    The status of the bandwidth, including "InUse" and "Idle".
    """
    def __init__(__self__, resource_name, opts=None, bandwidth=None, charge_type=None, description=None, geographic_region_ids=None, name=None, period=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a CEN bandwidth package resource. The CEN bandwidth package is an abstracted object that includes an interconnection bandwidth and interconnection areas. To buy a bandwidth package, you must specify the areas to connect. An area consists of one or more Alibaba Cloud regions. The areas in CEN include Mainland China, Asia Pacific, North America, and Europe.
        
        For information about CEN and how to use it, see [Manage bandwidth packages](https://www.alibabacloud.com/help/doc-detail/65982.htm).
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[float] bandwidth: The bandwidth in Mbps of the bandwidth package. Cannot be less than 2Mbps.
        :param pulumi.Input[str] charge_type: The billing method. Valid value: PostPaid | PrePaid. Default to PostPaid. If set to PrePaid, the bandwidth package can't be deleted before expired time.
        :param pulumi.Input[str] description: The description of the bandwidth package. Default to null.
        :param pulumi.Input[list] geographic_region_ids: List of the two areas to connect. Valid value: China | North-America | Asia-Pacific | Europe | Middle-East.
        :param pulumi.Input[str] name: The name of the bandwidth package. Defaults to null.
        :param pulumi.Input[float] period: The purchase period in month. Valid value: 1, 2, 3, 6, 12. Default to 1.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/r/cen_bandwidth_package.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if bandwidth is None:
                raise TypeError("Missing required property 'bandwidth'")
            __props__['bandwidth'] = bandwidth
            __props__['charge_type'] = charge_type
            __props__['description'] = description
            if geographic_region_ids is None:
                raise TypeError("Missing required property 'geographic_region_ids'")
            __props__['geographic_region_ids'] = geographic_region_ids
            __props__['name'] = name
            __props__['period'] = period
            __props__['expired_time'] = None
            __props__['status'] = None
        super(BandwidthPackage, __self__).__init__(
            'alicloud:cen/bandwidthPackage:BandwidthPackage',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, bandwidth=None, charge_type=None, description=None, expired_time=None, geographic_region_ids=None, name=None, period=None, status=None):
        """
        Get an existing BandwidthPackage resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[float] bandwidth: The bandwidth in Mbps of the bandwidth package. Cannot be less than 2Mbps.
        :param pulumi.Input[str] charge_type: The billing method. Valid value: PostPaid | PrePaid. Default to PostPaid. If set to PrePaid, the bandwidth package can't be deleted before expired time.
        :param pulumi.Input[str] description: The description of the bandwidth package. Default to null.
        :param pulumi.Input[str] expired_time: The time of the bandwidth package to expire.
        :param pulumi.Input[list] geographic_region_ids: List of the two areas to connect. Valid value: China | North-America | Asia-Pacific | Europe | Middle-East.
        :param pulumi.Input[str] name: The name of the bandwidth package. Defaults to null.
        :param pulumi.Input[float] period: The purchase period in month. Valid value: 1, 2, 3, 6, 12. Default to 1.
        :param pulumi.Input[str] status: The status of the bandwidth, including "InUse" and "Idle".

        > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/r/cen_bandwidth_package.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["bandwidth"] = bandwidth
        __props__["charge_type"] = charge_type
        __props__["description"] = description
        __props__["expired_time"] = expired_time
        __props__["geographic_region_ids"] = geographic_region_ids
        __props__["name"] = name
        __props__["period"] = period
        __props__["status"] = status
        return BandwidthPackage(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

