# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

_SNAKE_TO_CAMEL_CASE_TABLE = {
    "access_group_name": "accessGroupName",
    "access_key": "accessKey",
    "access_point_id": "accessPointId",
    "access_rule_id": "accessRuleId",
    "accessed_by": "accessedBy",
    "account_alias": "accountAlias",
    "account_description": "accountDescription",
    "account_id": "accountId",
    "account_name": "accountName",
    "account_password": "accountPassword",
    "account_privilege": "accountPrivilege",
    "account_type": "accountType",
    "acl_id": "aclId",
    "acl_operation_type": "aclOperationType",
    "acl_resource_name": "aclResourceName",
    "acl_resource_pattern_type": "aclResourcePatternType",
    "acl_resource_type": "aclResourceType",
    "acl_status": "aclStatus",
    "acl_type": "aclType",
    "address_ip_version": "addressIpVersion",
    "address_type": "addressType",
    "adjustment_type": "adjustmentType",
    "adjustment_value": "adjustmentValue",
    "agent_version": "agentVersion",
    "alarm_actions": "alarmActions",
    "alicloud_certifacte_id": "alicloudCertifacteId",
    "alicloud_certifacte_name": "alicloudCertifacteName",
    "alicloud_certificate_id": "alicloudCertificateId",
    "alicloud_certificate_name": "alicloudCertificateName",
    "alicloud_certificate_region_id": "alicloudCertificateRegionId",
    "allocate_public_ip": "allocatePublicIp",
    "allocation_id": "allocationId",
    "api_id": "apiId",
    "api_server_internet": "apiServerInternet",
    "api_server_intranet": "apiServerIntranet",
    "app_id": "appId",
    "append_meta": "appendMeta",
    "archive_backup_keep_count": "archiveBackupKeepCount",
    "archive_backup_keep_policy": "archiveBackupKeepPolicy",
    "archive_backup_retention_period": "archiveBackupRetentionPeriod",
    "assume_role": "assumeRole",
    "attachment_count": "attachmentCount",
    "auth_config": "authConfig",
    "auth_type": "authType",
    "auto_create": "autoCreate",
    "auto_release_time": "autoReleaseTime",
    "auto_renew": "autoRenew",
    "auto_renew_period": "autoRenewPeriod",
    "auto_split": "autoSplit",
    "auto_upgrade_minor_version": "autoUpgradeMinorVersion",
    "availability_zone": "availabilityZone",
    "backend_port": "backendPort",
    "backend_servers": "backendServers",
    "backup_id": "backupId",
    "backup_periods": "backupPeriods",
    "backup_retention_period": "backupRetentionPeriod",
    "backup_time": "backupTime",
    "bandwidth_limit": "bandwidthLimit",
    "bandwidth_package_id": "bandwidthPackageId",
    "bandwidth_package_ids": "bandwidthPackageIds",
    "bandwidth_packages": "bandwidthPackages",
    "base_bandwidth": "baseBandwidth",
    "block_ips": "blockIps",
    "blue_green": "blueGreen",
    "blue_green_confirm": "blueGreenConfirm",
    "business_status": "businessStatus",
    "ca_cert": "caCert",
    "ca_certificate": "caCertificate",
    "cache_configs": "cacheConfigs",
    "cache_control": "cacheControl",
    "ccn_id": "ccnId",
    "cdn_type": "cdnType",
    "cen_id": "cenId",
    "cen_owner_id": "cenOwnerId",
    "cen_uid": "cenUid",
    "certificate_config": "certificateConfig",
    "character_set": "characterSet",
    "character_set_name": "characterSetName",
    "charge_type": "chargeType",
    "child_instance_id": "childInstanceId",
    "child_instance_owner_id": "childInstanceOwnerId",
    "child_instance_region_id": "childInstanceRegionId",
    "cidr_block": "cidrBlock",
    "cidr_ip": "cidrIp",
    "ciphertext_blob": "ciphertextBlob",
    "client_cert": "clientCert",
    "client_config": "clientConfig",
    "client_ip": "clientIp",
    "client_ip_pool": "clientIpPool",
    "client_key": "clientKey",
    "cloud_monitor_group_id": "cloudMonitorGroupId",
    "cluster_ca_cert": "clusterCaCert",
    "cluster_id": "clusterId",
    "cluster_name": "clusterName",
    "cluster_network_type": "clusterNetworkType",
    "cluster_type": "clusterType",
    "code_checksum": "codeChecksum",
    "compact_topic": "compactTopic",
    "comparison_operator": "comparisonOperator",
    "compress_type": "compressType",
    "config_mns": "configMns",
    "configuration_source": "configurationSource",
    "connection_domain": "connectionDomain",
    "connection_prefix": "connectionPrefix",
    "connection_string": "connectionString",
    "constant_parameters": "constantParameters",
    "consumer_id": "consumerId",
    "contact_groups": "contactGroups",
    "content_disposition": "contentDisposition",
    "content_encoding": "contentEncoding",
    "content_length": "contentLength",
    "content_md5": "contentMd5",
    "content_type": "contentType",
    "cookie_timeout": "cookieTimeout",
    "cool_down_duration": "coolDownDuration",
    "cors_rules": "corsRules",
    "coupon_id": "couponId",
    "create_time": "createTime",
    "creation_date": "creationDate",
    "creation_time": "creationTime",
    "credit_specification": "creditSpecification",
    "customer_gateway_id": "customerGatewayId",
    "data_disks": "dataDisks",
    "data_node_amount": "dataNodeAmount",
    "data_node_disk_size": "dataNodeDiskSize",
    "data_node_disk_type": "dataNodeDiskType",
    "data_node_spec": "dataNodeSpec",
    "db_cluster_id": "dbClusterId",
    "db_description": "dbDescription",
    "db_endpoint_id": "dbEndpointId",
    "db_instance_class": "dbInstanceClass",
    "db_instance_ids": "dbInstanceIds",
    "db_instance_storage": "dbInstanceStorage",
    "db_instance_storage_type": "dbInstanceStorageType",
    "db_name": "dbName",
    "db_names": "dbNames",
    "db_node_class": "dbNodeClass",
    "db_type": "dbType",
    "db_version": "dbVersion",
    "default_cooldown": "defaultCooldown",
    "default_domain": "defaultDomain",
    "default_result": "defaultResult",
    "default_visibility": "defaultVisibility",
    "defer_scale_in_duration": "deferScaleInDuration",
    "delay_seconds": "delaySeconds",
    "delete_auto_snapshot": "deleteAutoSnapshot",
    "delete_protection": "deleteProtection",
    "delete_protection_validation": "deleteProtectionValidation",
    "delete_with_instance": "deleteWithInstance",
    "deletion_protection": "deletionProtection",
    "deletion_window_in_days": "deletionWindowInDays",
    "deploy_type": "deployType",
    "deposit_type": "depositType",
    "dest_cidr": "destCidr",
    "dest_port_range": "destPortRange",
    "destination_cidrblock": "destinationCidrblock",
    "deviation_cell_version_in_sec": "deviationCellVersionInSec",
    "device_name": "deviceName",
    "disable_scale_in": "disableScaleIn",
    "disk_category": "diskCategory",
    "disk_device_mappings": "diskDeviceMappings",
    "disk_id": "diskId",
    "disk_size": "diskSize",
    "disk_type": "diskType",
    "display_name": "displayName",
    "distribution_type": "distributionType",
    "dns_servers": "dnsServers",
    "domain_count": "domainCount",
    "domain_id": "domainId",
    "domain_list": "domainList",
    "domain_name": "domainName",
    "dry_run": "dryRun",
    "eas_enable": "easEnable",
    "ecs_role_name": "ecsRoleName",
    "effect_immediately": "effectImmediately",
    "effective_interval": "effectiveInterval",
    "eip_max": "eipMax",
    "emr_ver": "emrVer",
    "enable_auto_snapshot": "enableAutoSnapshot",
    "enable_backup_log": "enableBackupLog",
    "enable_http2": "enableHttp2",
    "enable_ipsec": "enableIpsec",
    "enable_ssh": "enableSsh",
    "enable_ssl": "enableSsl",
    "enable_web_tracking": "enableWebTracking",
    "encrypted_secret": "encryptedSecret",
    "encryption_context": "encryptionContext",
    "end_time": "endTime",
    "endpoint_public_access_enabled": "endpointPublicAccessEnabled",
    "engine_version": "engineVersion",
    "entry_lists": "entryLists",
    "environment_variables": "environmentVariables",
    "established_timeout": "establishedTimeout",
    "estimated_instance_warmup": "estimatedInstanceWarmup",
    "evaluation_count": "evaluationCount",
    "event_rw": "eventRw",
    "expired_time": "expiredTime",
    "external_ip": "externalIp",
    "external_port": "externalPort",
    "extranet_endpoint": "extranetEndpoint",
    "fc_service_config": "fcServiceConfig",
    "field_searches": "fieldSearches",
    "file_system_id": "fileSystemId",
    "filter_tag": "filterTag",
    "finger_print": "fingerPrint",
    "force_delete": "forceDelete",
    "force_destroy": "forceDestroy",
    "force_update": "forceUpdate",
    "forward_entry_id": "forwardEntryId",
    "forward_port": "forwardPort",
    "forward_table_id": "forwardTableId",
    "forward_table_ids": "forwardTableIds",
    "frontend_port": "frontendPort",
    "full_text": "fullText",
    "function_args": "functionArgs",
    "function_id": "functionId",
    "function_name": "functionName",
    "geographic_region_ids": "geographicRegionIds",
    "group_id": "groupId",
    "group_name": "groupName",
    "hard_expiry": "hardExpiry",
    "havip_id": "havipId",
    "health_check": "healthCheck",
    "health_check_connect_port": "healthCheckConnectPort",
    "health_check_domain": "healthCheckDomain",
    "health_check_http_code": "healthCheckHttpCode",
    "health_check_interval": "healthCheckInterval",
    "health_check_method": "healthCheckMethod",
    "health_check_source_ip": "healthCheckSourceIp",
    "health_check_target_ip": "healthCheckTargetIp",
    "health_check_timeout": "healthCheckTimeout",
    "health_check_type": "healthCheckType",
    "health_check_uri": "healthCheckUri",
    "healthy_threshold": "healthyThreshold",
    "heartbeat_timeout": "heartbeatTimeout",
    "high_availability_enable": "highAvailabilityEnable",
    "high_space_usage_protection": "highSpaceUsageProtection",
    "host_groups": "hostGroups",
    "host_name": "hostName",
    "host_record": "hostRecord",
    "http_header_configs": "httpHeaderConfigs",
    "http_service_config": "httpServiceConfig",
    "http_vpc_service_config": "httpVpcServiceConfig",
    "identify_lists": "identifyLists",
    "identify_type": "identifyType",
    "idle_timeout": "idleTimeout",
    "ike_configs": "ikeConfigs",
    "image_id": "imageId",
    "image_name": "imageName",
    "image_owner_alias": "imageOwnerAlias",
    "include_data_disks": "includeDataDisks",
    "inner_access": "innerAccess",
    "inner_access_policy": "innerAccessPolicy",
    "input_detail": "inputDetail",
    "input_type": "inputType",
    "install_cloud_monitor": "installCloudMonitor",
    "instance_amount": "instanceAmount",
    "instance_charge_type": "instanceChargeType",
    "instance_class": "instanceClass",
    "instance_group_count": "instanceGroupCount",
    "instance_id": "instanceId",
    "instance_ids": "instanceIds",
    "instance_name": "instanceName",
    "instance_port": "instancePort",
    "instance_series": "instanceSeries",
    "instance_status": "instanceStatus",
    "instance_storage": "instanceStorage",
    "instance_type": "instanceType",
    "instance_types": "instanceTypes",
    "interface_id": "interfaceId",
    "internal_ip": "internalIp",
    "internal_port": "internalPort",
    "internet_access": "internetAccess",
    "internet_charge_type": "internetChargeType",
    "internet_ip": "internetIp",
    "internet_max_bandwidth_in": "internetMaxBandwidthIn",
    "internet_max_bandwidth_out": "internetMaxBandwidthOut",
    "intranet_endpoint": "intranetEndpoint",
    "io_max": "ioMax",
    "io_optimized": "ioOptimized",
    "ip_address": "ipAddress",
    "ip_count": "ipCount",
    "ip_protocol": "ipProtocol",
    "ip_type": "ipType",
    "ip_version": "ipVersion",
    "ipsec_configs": "ipsecConfigs",
    "is_default": "isDefault",
    "is_enabled": "isEnabled",
    "is_open_public_ip": "isOpenPublicIp",
    "is_outdated": "isOutdated",
    "is_ptr": "isPtr",
    "key_file": "keyFile",
    "key_fingerprint": "keyFingerprint",
    "key_id": "keyId",
    "key_name": "keyName",
    "key_name_prefix": "keyNamePrefix",
    "key_pair_name": "keyPairName",
    "key_usage": "keyUsage",
    "kibana_domain": "kibanaDomain",
    "kibana_port": "kibanaPort",
    "kibana_whitelists": "kibanaWhitelists",
    "kms_encrypted_password": "kmsEncryptedPassword",
    "kms_encryption_context": "kmsEncryptionContext",
    "kms_key_id": "kmsKeyId",
    "kube_config": "kubeConfig",
    "last_modified": "lastModified",
    "last_modify_time": "lastModifyTime",
    "latest_image": "latestImage",
    "launch_expiration_time": "launchExpirationTime",
    "launch_time": "launchTime",
    "lb_port": "lbPort",
    "lb_protocol": "lbProtocol",
    "license_code": "licenseCode",
    "license_type": "licenseType",
    "life_cycle": "lifeCycle",
    "lifecycle_rules": "lifecycleRules",
    "lifecycle_transition": "lifecycleTransition",
    "limit_type": "limitType",
    "listener_forward": "listenerForward",
    "listener_sync": "listenerSync",
    "load_balancer_id": "loadBalancerId",
    "loadbalancer_ids": "loadbalancerIds",
    "local_log_retention_hours": "localLogRetentionHours",
    "local_log_retention_space": "localLogRetentionSpace",
    "local_subnet": "localSubnet",
    "local_subnets": "localSubnets",
    "local_topic": "localTopic",
    "log_backup": "logBackup",
    "log_backup_frequency": "logBackupFrequency",
    "log_backup_retention_period": "logBackupRetentionPeriod",
    "log_config": "logConfig",
    "log_endpoint": "logEndpoint",
    "log_retention_period": "logRetentionPeriod",
    "log_sample": "logSample",
    "logging_enabled": "loggingEnabled",
    "logging_isenable": "loggingIsenable",
    "logtail_config_name": "logtailConfigName",
    "machine_group_name": "machineGroupName",
    "maintain_end_time": "maintainEndTime",
    "maintain_start_time": "maintainStartTime",
    "maintain_time": "maintainTime",
    "master_auto_renew": "masterAutoRenew",
    "master_auto_renew_period": "masterAutoRenewPeriod",
    "master_db_instance_id": "masterDbInstanceId",
    "master_disk_category": "masterDiskCategory",
    "master_disk_size": "masterDiskSize",
    "master_instance_charge_type": "masterInstanceChargeType",
    "master_instance_type": "masterInstanceType",
    "master_instance_types": "masterInstanceTypes",
    "master_node_spec": "masterNodeSpec",
    "master_nodes": "masterNodes",
    "master_period": "masterPeriod",
    "master_period_unit": "masterPeriodUnit",
    "master_public_ip": "masterPublicIp",
    "master_pwd": "masterPwd",
    "master_slave_server_group_id": "masterSlaveServerGroupId",
    "master_zone_id": "masterZoneId",
    "max_bandwidth_abs": "maxBandwidthAbs",
    "max_bandwidth_percent": "maxBandwidthPercent",
    "max_connections": "maxConnections",
    "max_delay_time": "maxDelayTime",
    "max_login_attempts": "maxLoginAttempts",
    "max_password_age": "maxPasswordAge",
    "max_size": "maxSize",
    "max_split_shard_count": "maxSplitShardCount",
    "max_version": "maxVersion",
    "maximum_message_size": "maximumMessageSize",
    "memory_size": "memorySize",
    "message_retention_period": "messageRetentionPeriod",
    "message_type": "messageType",
    "metric_name": "metricName",
    "metric_type": "metricType",
    "mfa_bind_required": "mfaBindRequired",
    "min_bandwidth_abs": "minBandwidthAbs",
    "min_bandwidth_percent": "minBandwidthPercent",
    "min_size": "minSize",
    "minimum_password_length": "minimumPasswordLength",
    "mns_endpoint": "mnsEndpoint",
    "mock_service_config": "mockServiceConfig",
    "mongo_lists": "mongoLists",
    "monitoring_period": "monitoringPeriod",
    "multi_az_policy": "multiAzPolicy",
    "name_prefix": "namePrefix",
    "nat_gateway_id": "natGatewayId",
    "need_slb": "needSlb",
    "net_type": "netType",
    "network_acl_id": "networkAclId",
    "network_interface_id": "networkInterfaceId",
    "network_interfaces": "networkInterfaces",
    "network_type": "networkType",
    "new_nat_gateway": "newNatGateway",
    "next_hop": "nextHop",
    "nexthop_id": "nexthopId",
    "nexthop_type": "nexthopType",
    "nic_type": "nicType",
    "node_cidr_mask": "nodeCidrMask",
    "node_number": "nodeNumber",
    "notification_arn": "notificationArn",
    "notification_metadata": "notificationMetadata",
    "notification_types": "notificationTypes",
    "notify_content_format": "notifyContentFormat",
    "notify_strategy": "notifyStrategy",
    "offering_type": "offeringType",
    "on_demand_base_capacity": "onDemandBaseCapacity",
    "on_demand_percentage_above_base_capacity": "onDemandPercentageAboveBaseCapacity",
    "opposite_access_point_id": "oppositeAccessPointId",
    "opposite_interface_id": "oppositeInterfaceId",
    "opposite_interface_owner_id": "oppositeInterfaceOwnerId",
    "opposite_region": "oppositeRegion",
    "opposite_router_id": "oppositeRouterId",
    "opposite_router_type": "oppositeRouterType",
    "optimize_enable": "optimizeEnable",
    "option_software_lists": "optionSoftwareLists",
    "os_type": "osType",
    "oss_bucket": "ossBucket",
    "oss_bucket_name": "ossBucketName",
    "oss_key": "ossKey",
    "oss_key_prefix": "ossKeyPrefix",
    "oss_prefix": "ossPrefix",
    "ots_instance_name": "otsInstanceName",
    "output_type": "outputType",
    "package_version": "packageVersion",
    "page404_config": "page404Config",
    "page_compress_enable": "pageCompressEnable",
    "paid_type": "paidType",
    "parameter_filter_config": "parameterFilterConfig",
    "partition_num": "partitionNum",
    "password_inherit": "passwordInherit",
    "password_reset_required": "passwordResetRequired",
    "password_reuse_prevention": "passwordReusePrevention",
    "pay_type": "payType",
    "percent_source_type": "percentSourceType",
    "period_unit": "periodUnit",
    "persistence_timeout": "persistenceTimeout",
    "pgp_key": "pgpKey",
    "plan_code": "planCode",
    "pod_cidr": "podCidr",
    "policy_name": "policyName",
    "policy_type": "policyType",
    "polling_wait_seconds": "pollingWaitSeconds",
    "port_count": "portCount",
    "port_range": "portRange",
    "preferred_backup_periods": "preferredBackupPeriods",
    "preferred_backup_time": "preferredBackupTime",
    "pricing_cycle": "pricingCycle",
    "primary_keys": "primaryKeys",
    "private_ip": "privateIp",
    "private_ip_address": "privateIpAddress",
    "private_ips": "privateIps",
    "private_ips_count": "privateIpsCount",
    "private_key": "privateKey",
    "private_whitelists": "privateWhitelists",
    "private_zone": "privateZone",
    "product_code": "productCode",
    "project_name": "projectName",
    "protocol_type": "protocolType",
    "proxy_pattern": "proxyPattern",
    "public_ip": "publicIp",
    "public_key": "publicKey",
    "public_whitelists": "publicWhitelists",
    "publish_vpc": "publishVpc",
    "qos_id": "qosId",
    "ram_role_name": "ramRoleName",
    "ram_users": "ramUsers",
    "range_enable": "rangeEnable",
    "read_enable": "readEnable",
    "record_count": "recordCount",
    "record_id": "recordId",
    "record_schema": "recordSchema",
    "record_type": "recordType",
    "recurrence_end_time": "recurrenceEndTime",
    "recurrence_type": "recurrenceType",
    "recurrence_value": "recurrenceValue",
    "refer_config": "referConfig",
    "referer_config": "refererConfig",
    "region_ids": "regionIds",
    "related_cluster_id": "relatedClusterId",
    "release_eip": "releaseEip",
    "release_time": "releaseTime",
    "remote_subnets": "remoteSubnets",
    "removal_policies": "removalPolicies",
    "renewal_status": "renewalStatus",
    "repeat_weekdays": "repeatWeekdays",
    "replica_set_name": "replicaSetName",
    "replication_factor": "replicationFactor",
    "repo_type": "repoType",
    "request_config": "requestConfig",
    "request_parameters": "requestParameters",
    "request_timeout": "requestTimeout",
    "require_lowercase_characters": "requireLowercaseCharacters",
    "require_numbers": "requireNumbers",
    "require_symbols": "requireSymbols",
    "require_uppercase_characters": "requireUppercaseCharacters",
    "resource_group_id": "resourceGroupId",
    "resource_record": "resourceRecord",
    "retention_days": "retentionDays",
    "retention_period": "retentionPeriod",
    "role_id": "roleId",
    "role_name": "roleName",
    "route_dest": "routeDest",
    "route_table_id": "routeTableId",
    "router_id": "routerId",
    "router_table_id": "routerTableId",
    "router_type": "routerType",
    "rw_access_type": "rwAccessType",
    "sag_id": "sagId",
    "scaling_configuration_name": "scalingConfigurationName",
    "scaling_group_id": "scalingGroupId",
    "scaling_group_name": "scalingGroupName",
    "scaling_rule_name": "scalingRuleName",
    "scaling_rule_type": "scalingRuleType",
    "scheduled_action": "scheduledAction",
    "scheduled_task_name": "scheduledTaskName",
    "secret_file": "secretFile",
    "secret_key": "secretKey",
    "security_enhancement_strategy": "securityEnhancementStrategy",
    "security_group_id": "securityGroupId",
    "security_group_ids": "securityGroupIds",
    "security_group_type": "securityGroupType",
    "security_groups": "securityGroups",
    "security_ip_lists": "securityIpLists",
    "security_ip_mode": "securityIpMode",
    "security_ips": "securityIps",
    "security_token": "securityToken",
    "server_certificate": "serverCertificate",
    "server_certificate_id": "serverCertificateId",
    "server_group_id": "serverGroupId",
    "server_side_encryption": "serverSideEncryption",
    "server_side_encryption_rule": "serverSideEncryptionRule",
    "server_type": "serverType",
    "service_bandwidth": "serviceBandwidth",
    "service_cidr": "serviceCidr",
    "service_domain": "serviceDomain",
    "service_id": "serviceId",
    "service_type": "serviceType",
    "shard_count": "shardCount",
    "shard_lists": "shardLists",
    "shared_credentials_file": "sharedCredentialsFile",
    "silence_time": "silenceTime",
    "skip_region_validation": "skipRegionValidation",
    "slave_zone_id": "slaveZoneId",
    "slb_id": "slbId",
    "slb_internet": "slbInternet",
    "slb_internet_enabled": "slbInternetEnabled",
    "slb_intranet": "slbIntranet",
    "sls_project_arn": "slsProjectArn",
    "sls_write_role_arn": "slsWriteRoleArn",
    "snapshot_id": "snapshotId",
    "snat_entry_id": "snatEntryId",
    "snat_ip": "snatIp",
    "snat_table_id": "snatTableId",
    "snat_table_ids": "snatTableIds",
    "source_arn": "sourceArn",
    "source_cidr": "sourceCidr",
    "source_cidr_ip": "sourceCidrIp",
    "source_group_owner_account": "sourceGroupOwnerAccount",
    "source_image_id": "sourceImageId",
    "source_port": "sourcePort",
    "source_port_range": "sourcePortRange",
    "source_region_id": "sourceRegionId",
    "source_security_group_id": "sourceSecurityGroupId",
    "source_type": "sourceType",
    "source_vswitch_id": "sourceVswitchId",
    "spec_type": "specType",
    "spot_instance_pools": "spotInstancePools",
    "spot_instance_remedy": "spotInstanceRemedy",
    "spot_price_limit": "spotPriceLimit",
    "spot_strategy": "spotStrategy",
    "sql_collector_config_value": "sqlCollectorConfigValue",
    "sql_collector_status": "sqlCollectorStatus",
    "ssh_enable": "sshEnable",
    "ssl_certificate_id": "sslCertificateId",
    "ssl_connections": "sslConnections",
    "ssl_vpn_server_id": "sslVpnServerId",
    "stage_name": "stageName",
    "stage_names": "stageNames",
    "start_time": "startTime",
    "step_adjustments": "stepAdjustments",
    "sticky_session": "stickySession",
    "sticky_session_type": "stickySessionType",
    "storage_class": "storageClass",
    "storage_engine": "storageEngine",
    "storage_type": "storageType",
    "sub_domain": "subDomain",
    "sub_id": "subId",
    "subnet_id": "subnetId",
    "system_disk_category": "systemDiskCategory",
    "system_disk_description": "systemDiskDescription",
    "system_disk_name": "systemDiskName",
    "system_disk_size": "systemDiskSize",
    "system_parameters": "systemParameters",
    "table_name": "tableName",
    "target_value": "targetValue",
    "task_enabled": "taskEnabled",
    "time_points": "timePoints",
    "time_to_live": "timeToLive",
    "tls_cipher_policy": "tlsCipherPolicy",
    "topic_name": "topicName",
    "topic_quota": "topicQuota",
    "trigger_id": "triggerId",
    "triggered_count": "triggeredCount",
    "unhealthy_threshold": "unhealthyThreshold",
    "update_time": "updateTime",
    "use_local_metadb": "useLocalMetadb",
    "user_access_type": "userAccessType",
    "user_ca": "userCa",
    "user_client_ip": "userClientIp",
    "user_data": "userData",
    "user_defined_emr_ecs_role": "userDefinedEmrEcsRole",
    "user_mail": "userMail",
    "user_name": "userName",
    "user_names": "userNames",
    "version_id": "versionId",
    "video_seek_enable": "videoSeekEnable",
    "visibility_timeout": "visibilityTimeout",
    "volume_tags": "volumeTags",
    "vpc_auth_mode": "vpcAuthMode",
    "vpc_config": "vpcConfig",
    "vpc_domain": "vpcDomain",
    "vpc_id": "vpcId",
    "vpc_ids": "vpcIds",
    "vpc_name": "vpcName",
    "vpn_gateway_id": "vpnGatewayId",
    "vserver_groups": "vserverGroups",
    "vswitch_id": "vswitchId",
    "vswitch_ids": "vswitchIds",
    "worker_auto_renew": "workerAutoRenew",
    "worker_auto_renew_period": "workerAutoRenewPeriod",
    "worker_data_disk_category": "workerDataDiskCategory",
    "worker_data_disk_size": "workerDataDiskSize",
    "worker_disk_category": "workerDiskCategory",
    "worker_disk_size": "workerDiskSize",
    "worker_instance_charge_type": "workerInstanceChargeType",
    "worker_instance_type": "workerInstanceType",
    "worker_instance_types": "workerInstanceTypes",
    "worker_nodes": "workerNodes",
    "worker_number": "workerNumber",
    "worker_numbers": "workerNumbers",
    "worker_period": "workerPeriod",
    "worker_period_unit": "workerPeriodUnit",
    "x_forwarded_for": "xForwardedFor",
    "zone_count": "zoneCount",
    "zone_id": "zoneId",
}

_CAMEL_TO_SNAKE_CASE_TABLE = {
    "accessGroupName": "access_group_name",
    "accessKey": "access_key",
    "accessPointId": "access_point_id",
    "accessRuleId": "access_rule_id",
    "accessedBy": "accessed_by",
    "accountAlias": "account_alias",
    "accountDescription": "account_description",
    "accountId": "account_id",
    "accountName": "account_name",
    "accountPassword": "account_password",
    "accountPrivilege": "account_privilege",
    "accountType": "account_type",
    "aclId": "acl_id",
    "aclOperationType": "acl_operation_type",
    "aclResourceName": "acl_resource_name",
    "aclResourcePatternType": "acl_resource_pattern_type",
    "aclResourceType": "acl_resource_type",
    "aclStatus": "acl_status",
    "aclType": "acl_type",
    "addressIpVersion": "address_ip_version",
    "addressType": "address_type",
    "adjustmentType": "adjustment_type",
    "adjustmentValue": "adjustment_value",
    "agentVersion": "agent_version",
    "alarmActions": "alarm_actions",
    "alicloudCertifacteId": "alicloud_certifacte_id",
    "alicloudCertifacteName": "alicloud_certifacte_name",
    "alicloudCertificateId": "alicloud_certificate_id",
    "alicloudCertificateName": "alicloud_certificate_name",
    "alicloudCertificateRegionId": "alicloud_certificate_region_id",
    "allocatePublicIp": "allocate_public_ip",
    "allocationId": "allocation_id",
    "apiId": "api_id",
    "apiServerInternet": "api_server_internet",
    "apiServerIntranet": "api_server_intranet",
    "appId": "app_id",
    "appendMeta": "append_meta",
    "archiveBackupKeepCount": "archive_backup_keep_count",
    "archiveBackupKeepPolicy": "archive_backup_keep_policy",
    "archiveBackupRetentionPeriod": "archive_backup_retention_period",
    "assumeRole": "assume_role",
    "attachmentCount": "attachment_count",
    "authConfig": "auth_config",
    "authType": "auth_type",
    "autoCreate": "auto_create",
    "autoReleaseTime": "auto_release_time",
    "autoRenew": "auto_renew",
    "autoRenewPeriod": "auto_renew_period",
    "autoSplit": "auto_split",
    "autoUpgradeMinorVersion": "auto_upgrade_minor_version",
    "availabilityZone": "availability_zone",
    "backendPort": "backend_port",
    "backendServers": "backend_servers",
    "backupId": "backup_id",
    "backupPeriods": "backup_periods",
    "backupRetentionPeriod": "backup_retention_period",
    "backupTime": "backup_time",
    "bandwidthLimit": "bandwidth_limit",
    "bandwidthPackageId": "bandwidth_package_id",
    "bandwidthPackageIds": "bandwidth_package_ids",
    "bandwidthPackages": "bandwidth_packages",
    "baseBandwidth": "base_bandwidth",
    "blockIps": "block_ips",
    "blueGreen": "blue_green",
    "blueGreenConfirm": "blue_green_confirm",
    "businessStatus": "business_status",
    "caCert": "ca_cert",
    "caCertificate": "ca_certificate",
    "cacheConfigs": "cache_configs",
    "cacheControl": "cache_control",
    "ccnId": "ccn_id",
    "cdnType": "cdn_type",
    "cenId": "cen_id",
    "cenOwnerId": "cen_owner_id",
    "cenUid": "cen_uid",
    "certificateConfig": "certificate_config",
    "characterSet": "character_set",
    "characterSetName": "character_set_name",
    "chargeType": "charge_type",
    "childInstanceId": "child_instance_id",
    "childInstanceOwnerId": "child_instance_owner_id",
    "childInstanceRegionId": "child_instance_region_id",
    "cidrBlock": "cidr_block",
    "cidrIp": "cidr_ip",
    "ciphertextBlob": "ciphertext_blob",
    "clientCert": "client_cert",
    "clientConfig": "client_config",
    "clientIp": "client_ip",
    "clientIpPool": "client_ip_pool",
    "clientKey": "client_key",
    "cloudMonitorGroupId": "cloud_monitor_group_id",
    "clusterCaCert": "cluster_ca_cert",
    "clusterId": "cluster_id",
    "clusterName": "cluster_name",
    "clusterNetworkType": "cluster_network_type",
    "clusterType": "cluster_type",
    "codeChecksum": "code_checksum",
    "compactTopic": "compact_topic",
    "comparisonOperator": "comparison_operator",
    "compressType": "compress_type",
    "configMns": "config_mns",
    "configurationSource": "configuration_source",
    "connectionDomain": "connection_domain",
    "connectionPrefix": "connection_prefix",
    "connectionString": "connection_string",
    "constantParameters": "constant_parameters",
    "consumerId": "consumer_id",
    "contactGroups": "contact_groups",
    "contentDisposition": "content_disposition",
    "contentEncoding": "content_encoding",
    "contentLength": "content_length",
    "contentMd5": "content_md5",
    "contentType": "content_type",
    "cookieTimeout": "cookie_timeout",
    "coolDownDuration": "cool_down_duration",
    "corsRules": "cors_rules",
    "couponId": "coupon_id",
    "createTime": "create_time",
    "creationDate": "creation_date",
    "creationTime": "creation_time",
    "creditSpecification": "credit_specification",
    "customerGatewayId": "customer_gateway_id",
    "dataDisks": "data_disks",
    "dataNodeAmount": "data_node_amount",
    "dataNodeDiskSize": "data_node_disk_size",
    "dataNodeDiskType": "data_node_disk_type",
    "dataNodeSpec": "data_node_spec",
    "dbClusterId": "db_cluster_id",
    "dbDescription": "db_description",
    "dbEndpointId": "db_endpoint_id",
    "dbInstanceClass": "db_instance_class",
    "dbInstanceIds": "db_instance_ids",
    "dbInstanceStorage": "db_instance_storage",
    "dbInstanceStorageType": "db_instance_storage_type",
    "dbName": "db_name",
    "dbNames": "db_names",
    "dbNodeClass": "db_node_class",
    "dbType": "db_type",
    "dbVersion": "db_version",
    "defaultCooldown": "default_cooldown",
    "defaultDomain": "default_domain",
    "defaultResult": "default_result",
    "defaultVisibility": "default_visibility",
    "deferScaleInDuration": "defer_scale_in_duration",
    "delaySeconds": "delay_seconds",
    "deleteAutoSnapshot": "delete_auto_snapshot",
    "deleteProtection": "delete_protection",
    "deleteProtectionValidation": "delete_protection_validation",
    "deleteWithInstance": "delete_with_instance",
    "deletionProtection": "deletion_protection",
    "deletionWindowInDays": "deletion_window_in_days",
    "deployType": "deploy_type",
    "depositType": "deposit_type",
    "destCidr": "dest_cidr",
    "destPortRange": "dest_port_range",
    "destinationCidrblock": "destination_cidrblock",
    "deviationCellVersionInSec": "deviation_cell_version_in_sec",
    "deviceName": "device_name",
    "disableScaleIn": "disable_scale_in",
    "diskCategory": "disk_category",
    "diskDeviceMappings": "disk_device_mappings",
    "diskId": "disk_id",
    "diskSize": "disk_size",
    "diskType": "disk_type",
    "displayName": "display_name",
    "distributionType": "distribution_type",
    "dnsServers": "dns_servers",
    "domainCount": "domain_count",
    "domainId": "domain_id",
    "domainList": "domain_list",
    "domainName": "domain_name",
    "dryRun": "dry_run",
    "easEnable": "eas_enable",
    "ecsRoleName": "ecs_role_name",
    "effectImmediately": "effect_immediately",
    "effectiveInterval": "effective_interval",
    "eipMax": "eip_max",
    "emrVer": "emr_ver",
    "enableAutoSnapshot": "enable_auto_snapshot",
    "enableBackupLog": "enable_backup_log",
    "enableHttp2": "enable_http2",
    "enableIpsec": "enable_ipsec",
    "enableSsh": "enable_ssh",
    "enableSsl": "enable_ssl",
    "enableWebTracking": "enable_web_tracking",
    "encryptedSecret": "encrypted_secret",
    "encryptionContext": "encryption_context",
    "endTime": "end_time",
    "endpointPublicAccessEnabled": "endpoint_public_access_enabled",
    "engineVersion": "engine_version",
    "entryLists": "entry_lists",
    "environmentVariables": "environment_variables",
    "establishedTimeout": "established_timeout",
    "estimatedInstanceWarmup": "estimated_instance_warmup",
    "evaluationCount": "evaluation_count",
    "eventRw": "event_rw",
    "expiredTime": "expired_time",
    "externalIp": "external_ip",
    "externalPort": "external_port",
    "extranetEndpoint": "extranet_endpoint",
    "fcServiceConfig": "fc_service_config",
    "fieldSearches": "field_searches",
    "fileSystemId": "file_system_id",
    "filterTag": "filter_tag",
    "fingerPrint": "finger_print",
    "forceDelete": "force_delete",
    "forceDestroy": "force_destroy",
    "forceUpdate": "force_update",
    "forwardEntryId": "forward_entry_id",
    "forwardPort": "forward_port",
    "forwardTableId": "forward_table_id",
    "forwardTableIds": "forward_table_ids",
    "frontendPort": "frontend_port",
    "fullText": "full_text",
    "functionArgs": "function_args",
    "functionId": "function_id",
    "functionName": "function_name",
    "geographicRegionIds": "geographic_region_ids",
    "groupId": "group_id",
    "groupName": "group_name",
    "hardExpiry": "hard_expiry",
    "havipId": "havip_id",
    "healthCheck": "health_check",
    "healthCheckConnectPort": "health_check_connect_port",
    "healthCheckDomain": "health_check_domain",
    "healthCheckHttpCode": "health_check_http_code",
    "healthCheckInterval": "health_check_interval",
    "healthCheckMethod": "health_check_method",
    "healthCheckSourceIp": "health_check_source_ip",
    "healthCheckTargetIp": "health_check_target_ip",
    "healthCheckTimeout": "health_check_timeout",
    "healthCheckType": "health_check_type",
    "healthCheckUri": "health_check_uri",
    "healthyThreshold": "healthy_threshold",
    "heartbeatTimeout": "heartbeat_timeout",
    "highAvailabilityEnable": "high_availability_enable",
    "highSpaceUsageProtection": "high_space_usage_protection",
    "hostGroups": "host_groups",
    "hostName": "host_name",
    "hostRecord": "host_record",
    "httpHeaderConfigs": "http_header_configs",
    "httpServiceConfig": "http_service_config",
    "httpVpcServiceConfig": "http_vpc_service_config",
    "identifyLists": "identify_lists",
    "identifyType": "identify_type",
    "idleTimeout": "idle_timeout",
    "ikeConfigs": "ike_configs",
    "imageId": "image_id",
    "imageName": "image_name",
    "imageOwnerAlias": "image_owner_alias",
    "includeDataDisks": "include_data_disks",
    "innerAccess": "inner_access",
    "innerAccessPolicy": "inner_access_policy",
    "inputDetail": "input_detail",
    "inputType": "input_type",
    "installCloudMonitor": "install_cloud_monitor",
    "instanceAmount": "instance_amount",
    "instanceChargeType": "instance_charge_type",
    "instanceClass": "instance_class",
    "instanceGroupCount": "instance_group_count",
    "instanceId": "instance_id",
    "instanceIds": "instance_ids",
    "instanceName": "instance_name",
    "instancePort": "instance_port",
    "instanceSeries": "instance_series",
    "instanceStatus": "instance_status",
    "instanceStorage": "instance_storage",
    "instanceType": "instance_type",
    "instanceTypes": "instance_types",
    "interfaceId": "interface_id",
    "internalIp": "internal_ip",
    "internalPort": "internal_port",
    "internetAccess": "internet_access",
    "internetChargeType": "internet_charge_type",
    "internetIp": "internet_ip",
    "internetMaxBandwidthIn": "internet_max_bandwidth_in",
    "internetMaxBandwidthOut": "internet_max_bandwidth_out",
    "intranetEndpoint": "intranet_endpoint",
    "ioMax": "io_max",
    "ioOptimized": "io_optimized",
    "ipAddress": "ip_address",
    "ipCount": "ip_count",
    "ipProtocol": "ip_protocol",
    "ipType": "ip_type",
    "ipVersion": "ip_version",
    "ipsecConfigs": "ipsec_configs",
    "isDefault": "is_default",
    "isEnabled": "is_enabled",
    "isOpenPublicIp": "is_open_public_ip",
    "isOutdated": "is_outdated",
    "isPtr": "is_ptr",
    "keyFile": "key_file",
    "keyFingerprint": "key_fingerprint",
    "keyId": "key_id",
    "keyName": "key_name",
    "keyNamePrefix": "key_name_prefix",
    "keyPairName": "key_pair_name",
    "keyUsage": "key_usage",
    "kibanaDomain": "kibana_domain",
    "kibanaPort": "kibana_port",
    "kibanaWhitelists": "kibana_whitelists",
    "kmsEncryptedPassword": "kms_encrypted_password",
    "kmsEncryptionContext": "kms_encryption_context",
    "kmsKeyId": "kms_key_id",
    "kubeConfig": "kube_config",
    "lastModified": "last_modified",
    "lastModifyTime": "last_modify_time",
    "latestImage": "latest_image",
    "launchExpirationTime": "launch_expiration_time",
    "launchTime": "launch_time",
    "lbPort": "lb_port",
    "lbProtocol": "lb_protocol",
    "licenseCode": "license_code",
    "licenseType": "license_type",
    "lifeCycle": "life_cycle",
    "lifecycleRules": "lifecycle_rules",
    "lifecycleTransition": "lifecycle_transition",
    "limitType": "limit_type",
    "listenerForward": "listener_forward",
    "listenerSync": "listener_sync",
    "loadBalancerId": "load_balancer_id",
    "loadbalancerIds": "loadbalancer_ids",
    "localLogRetentionHours": "local_log_retention_hours",
    "localLogRetentionSpace": "local_log_retention_space",
    "localSubnet": "local_subnet",
    "localSubnets": "local_subnets",
    "localTopic": "local_topic",
    "logBackup": "log_backup",
    "logBackupFrequency": "log_backup_frequency",
    "logBackupRetentionPeriod": "log_backup_retention_period",
    "logConfig": "log_config",
    "logEndpoint": "log_endpoint",
    "logRetentionPeriod": "log_retention_period",
    "logSample": "log_sample",
    "loggingEnabled": "logging_enabled",
    "loggingIsenable": "logging_isenable",
    "logtailConfigName": "logtail_config_name",
    "machineGroupName": "machine_group_name",
    "maintainEndTime": "maintain_end_time",
    "maintainStartTime": "maintain_start_time",
    "maintainTime": "maintain_time",
    "masterAutoRenew": "master_auto_renew",
    "masterAutoRenewPeriod": "master_auto_renew_period",
    "masterDbInstanceId": "master_db_instance_id",
    "masterDiskCategory": "master_disk_category",
    "masterDiskSize": "master_disk_size",
    "masterInstanceChargeType": "master_instance_charge_type",
    "masterInstanceType": "master_instance_type",
    "masterInstanceTypes": "master_instance_types",
    "masterNodeSpec": "master_node_spec",
    "masterNodes": "master_nodes",
    "masterPeriod": "master_period",
    "masterPeriodUnit": "master_period_unit",
    "masterPublicIp": "master_public_ip",
    "masterPwd": "master_pwd",
    "masterSlaveServerGroupId": "master_slave_server_group_id",
    "masterZoneId": "master_zone_id",
    "maxBandwidthAbs": "max_bandwidth_abs",
    "maxBandwidthPercent": "max_bandwidth_percent",
    "maxConnections": "max_connections",
    "maxDelayTime": "max_delay_time",
    "maxLoginAttempts": "max_login_attempts",
    "maxPasswordAge": "max_password_age",
    "maxSize": "max_size",
    "maxSplitShardCount": "max_split_shard_count",
    "maxVersion": "max_version",
    "maximumMessageSize": "maximum_message_size",
    "memorySize": "memory_size",
    "messageRetentionPeriod": "message_retention_period",
    "messageType": "message_type",
    "metricName": "metric_name",
    "metricType": "metric_type",
    "mfaBindRequired": "mfa_bind_required",
    "minBandwidthAbs": "min_bandwidth_abs",
    "minBandwidthPercent": "min_bandwidth_percent",
    "minSize": "min_size",
    "minimumPasswordLength": "minimum_password_length",
    "mnsEndpoint": "mns_endpoint",
    "mockServiceConfig": "mock_service_config",
    "mongoLists": "mongo_lists",
    "monitoringPeriod": "monitoring_period",
    "multiAzPolicy": "multi_az_policy",
    "namePrefix": "name_prefix",
    "natGatewayId": "nat_gateway_id",
    "needSlb": "need_slb",
    "netType": "net_type",
    "networkAclId": "network_acl_id",
    "networkInterfaceId": "network_interface_id",
    "networkInterfaces": "network_interfaces",
    "networkType": "network_type",
    "newNatGateway": "new_nat_gateway",
    "nextHop": "next_hop",
    "nexthopId": "nexthop_id",
    "nexthopType": "nexthop_type",
    "nicType": "nic_type",
    "nodeCidrMask": "node_cidr_mask",
    "nodeNumber": "node_number",
    "notificationArn": "notification_arn",
    "notificationMetadata": "notification_metadata",
    "notificationTypes": "notification_types",
    "notifyContentFormat": "notify_content_format",
    "notifyStrategy": "notify_strategy",
    "offeringType": "offering_type",
    "onDemandBaseCapacity": "on_demand_base_capacity",
    "onDemandPercentageAboveBaseCapacity": "on_demand_percentage_above_base_capacity",
    "oppositeAccessPointId": "opposite_access_point_id",
    "oppositeInterfaceId": "opposite_interface_id",
    "oppositeInterfaceOwnerId": "opposite_interface_owner_id",
    "oppositeRegion": "opposite_region",
    "oppositeRouterId": "opposite_router_id",
    "oppositeRouterType": "opposite_router_type",
    "optimizeEnable": "optimize_enable",
    "optionSoftwareLists": "option_software_lists",
    "osType": "os_type",
    "ossBucket": "oss_bucket",
    "ossBucketName": "oss_bucket_name",
    "ossKey": "oss_key",
    "ossKeyPrefix": "oss_key_prefix",
    "ossPrefix": "oss_prefix",
    "otsInstanceName": "ots_instance_name",
    "outputType": "output_type",
    "packageVersion": "package_version",
    "page404Config": "page404_config",
    "pageCompressEnable": "page_compress_enable",
    "paidType": "paid_type",
    "parameterFilterConfig": "parameter_filter_config",
    "partitionNum": "partition_num",
    "passwordInherit": "password_inherit",
    "passwordResetRequired": "password_reset_required",
    "passwordReusePrevention": "password_reuse_prevention",
    "payType": "pay_type",
    "percentSourceType": "percent_source_type",
    "periodUnit": "period_unit",
    "persistenceTimeout": "persistence_timeout",
    "pgpKey": "pgp_key",
    "planCode": "plan_code",
    "podCidr": "pod_cidr",
    "policyName": "policy_name",
    "policyType": "policy_type",
    "pollingWaitSeconds": "polling_wait_seconds",
    "portCount": "port_count",
    "portRange": "port_range",
    "preferredBackupPeriods": "preferred_backup_periods",
    "preferredBackupTime": "preferred_backup_time",
    "pricingCycle": "pricing_cycle",
    "primaryKeys": "primary_keys",
    "privateIp": "private_ip",
    "privateIpAddress": "private_ip_address",
    "privateIps": "private_ips",
    "privateIpsCount": "private_ips_count",
    "privateKey": "private_key",
    "privateWhitelists": "private_whitelists",
    "privateZone": "private_zone",
    "productCode": "product_code",
    "projectName": "project_name",
    "protocolType": "protocol_type",
    "proxyPattern": "proxy_pattern",
    "publicIp": "public_ip",
    "publicKey": "public_key",
    "publicWhitelists": "public_whitelists",
    "publishVpc": "publish_vpc",
    "qosId": "qos_id",
    "ramRoleName": "ram_role_name",
    "ramUsers": "ram_users",
    "rangeEnable": "range_enable",
    "readEnable": "read_enable",
    "recordCount": "record_count",
    "recordId": "record_id",
    "recordSchema": "record_schema",
    "recordType": "record_type",
    "recurrenceEndTime": "recurrence_end_time",
    "recurrenceType": "recurrence_type",
    "recurrenceValue": "recurrence_value",
    "referConfig": "refer_config",
    "refererConfig": "referer_config",
    "regionIds": "region_ids",
    "relatedClusterId": "related_cluster_id",
    "releaseEip": "release_eip",
    "releaseTime": "release_time",
    "remoteSubnets": "remote_subnets",
    "removalPolicies": "removal_policies",
    "renewalStatus": "renewal_status",
    "repeatWeekdays": "repeat_weekdays",
    "replicaSetName": "replica_set_name",
    "replicationFactor": "replication_factor",
    "repoType": "repo_type",
    "requestConfig": "request_config",
    "requestParameters": "request_parameters",
    "requestTimeout": "request_timeout",
    "requireLowercaseCharacters": "require_lowercase_characters",
    "requireNumbers": "require_numbers",
    "requireSymbols": "require_symbols",
    "requireUppercaseCharacters": "require_uppercase_characters",
    "resourceGroupId": "resource_group_id",
    "resourceRecord": "resource_record",
    "retentionDays": "retention_days",
    "retentionPeriod": "retention_period",
    "roleId": "role_id",
    "roleName": "role_name",
    "routeDest": "route_dest",
    "routeTableId": "route_table_id",
    "routerId": "router_id",
    "routerTableId": "router_table_id",
    "routerType": "router_type",
    "rwAccessType": "rw_access_type",
    "sagId": "sag_id",
    "scalingConfigurationName": "scaling_configuration_name",
    "scalingGroupId": "scaling_group_id",
    "scalingGroupName": "scaling_group_name",
    "scalingRuleName": "scaling_rule_name",
    "scalingRuleType": "scaling_rule_type",
    "scheduledAction": "scheduled_action",
    "scheduledTaskName": "scheduled_task_name",
    "secretFile": "secret_file",
    "secretKey": "secret_key",
    "securityEnhancementStrategy": "security_enhancement_strategy",
    "securityGroupId": "security_group_id",
    "securityGroupIds": "security_group_ids",
    "securityGroupType": "security_group_type",
    "securityGroups": "security_groups",
    "securityIpLists": "security_ip_lists",
    "securityIpMode": "security_ip_mode",
    "securityIps": "security_ips",
    "securityToken": "security_token",
    "serverCertificate": "server_certificate",
    "serverCertificateId": "server_certificate_id",
    "serverGroupId": "server_group_id",
    "serverSideEncryption": "server_side_encryption",
    "serverSideEncryptionRule": "server_side_encryption_rule",
    "serverType": "server_type",
    "serviceBandwidth": "service_bandwidth",
    "serviceCidr": "service_cidr",
    "serviceDomain": "service_domain",
    "serviceId": "service_id",
    "serviceType": "service_type",
    "shardCount": "shard_count",
    "shardLists": "shard_lists",
    "sharedCredentialsFile": "shared_credentials_file",
    "silenceTime": "silence_time",
    "skipRegionValidation": "skip_region_validation",
    "slaveZoneId": "slave_zone_id",
    "slbId": "slb_id",
    "slbInternet": "slb_internet",
    "slbInternetEnabled": "slb_internet_enabled",
    "slbIntranet": "slb_intranet",
    "slsProjectArn": "sls_project_arn",
    "slsWriteRoleArn": "sls_write_role_arn",
    "snapshotId": "snapshot_id",
    "snatEntryId": "snat_entry_id",
    "snatIp": "snat_ip",
    "snatTableId": "snat_table_id",
    "snatTableIds": "snat_table_ids",
    "sourceArn": "source_arn",
    "sourceCidr": "source_cidr",
    "sourceCidrIp": "source_cidr_ip",
    "sourceGroupOwnerAccount": "source_group_owner_account",
    "sourceImageId": "source_image_id",
    "sourcePort": "source_port",
    "sourcePortRange": "source_port_range",
    "sourceRegionId": "source_region_id",
    "sourceSecurityGroupId": "source_security_group_id",
    "sourceType": "source_type",
    "sourceVswitchId": "source_vswitch_id",
    "specType": "spec_type",
    "spotInstancePools": "spot_instance_pools",
    "spotInstanceRemedy": "spot_instance_remedy",
    "spotPriceLimit": "spot_price_limit",
    "spotStrategy": "spot_strategy",
    "sqlCollectorConfigValue": "sql_collector_config_value",
    "sqlCollectorStatus": "sql_collector_status",
    "sshEnable": "ssh_enable",
    "sslCertificateId": "ssl_certificate_id",
    "sslConnections": "ssl_connections",
    "sslVpnServerId": "ssl_vpn_server_id",
    "stageName": "stage_name",
    "stageNames": "stage_names",
    "startTime": "start_time",
    "stepAdjustments": "step_adjustments",
    "stickySession": "sticky_session",
    "stickySessionType": "sticky_session_type",
    "storageClass": "storage_class",
    "storageEngine": "storage_engine",
    "storageType": "storage_type",
    "subDomain": "sub_domain",
    "subId": "sub_id",
    "subnetId": "subnet_id",
    "systemDiskCategory": "system_disk_category",
    "systemDiskDescription": "system_disk_description",
    "systemDiskName": "system_disk_name",
    "systemDiskSize": "system_disk_size",
    "systemParameters": "system_parameters",
    "tableName": "table_name",
    "targetValue": "target_value",
    "taskEnabled": "task_enabled",
    "timePoints": "time_points",
    "timeToLive": "time_to_live",
    "tlsCipherPolicy": "tls_cipher_policy",
    "topicName": "topic_name",
    "topicQuota": "topic_quota",
    "triggerId": "trigger_id",
    "triggeredCount": "triggered_count",
    "unhealthyThreshold": "unhealthy_threshold",
    "updateTime": "update_time",
    "useLocalMetadb": "use_local_metadb",
    "userAccessType": "user_access_type",
    "userCa": "user_ca",
    "userClientIp": "user_client_ip",
    "userData": "user_data",
    "userDefinedEmrEcsRole": "user_defined_emr_ecs_role",
    "userMail": "user_mail",
    "userName": "user_name",
    "userNames": "user_names",
    "versionId": "version_id",
    "videoSeekEnable": "video_seek_enable",
    "visibilityTimeout": "visibility_timeout",
    "volumeTags": "volume_tags",
    "vpcAuthMode": "vpc_auth_mode",
    "vpcConfig": "vpc_config",
    "vpcDomain": "vpc_domain",
    "vpcId": "vpc_id",
    "vpcIds": "vpc_ids",
    "vpcName": "vpc_name",
    "vpnGatewayId": "vpn_gateway_id",
    "vserverGroups": "vserver_groups",
    "vswitchId": "vswitch_id",
    "vswitchIds": "vswitch_ids",
    "workerAutoRenew": "worker_auto_renew",
    "workerAutoRenewPeriod": "worker_auto_renew_period",
    "workerDataDiskCategory": "worker_data_disk_category",
    "workerDataDiskSize": "worker_data_disk_size",
    "workerDiskCategory": "worker_disk_category",
    "workerDiskSize": "worker_disk_size",
    "workerInstanceChargeType": "worker_instance_charge_type",
    "workerInstanceType": "worker_instance_type",
    "workerInstanceTypes": "worker_instance_types",
    "workerNodes": "worker_nodes",
    "workerNumber": "worker_number",
    "workerNumbers": "worker_numbers",
    "workerPeriod": "worker_period",
    "workerPeriodUnit": "worker_period_unit",
    "xForwardedFor": "x_forwarded_for",
    "zoneCount": "zone_count",
    "zoneId": "zone_id",
}
