# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetDBAuditInstanceResult:
    """
    A collection of values returned by getDBAuditInstance.
    """
    def __init__(__self__, description_regex=None, descriptions=None, ids=None, instances=None, output_file=None, tags=None, id=None):
        if description_regex and not isinstance(description_regex, str):
            raise TypeError("Expected argument 'description_regex' to be a str")
        __self__.description_regex = description_regex
        if descriptions and not isinstance(descriptions, list):
            raise TypeError("Expected argument 'descriptions' to be a list")
        __self__.descriptions = descriptions
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        __self__.ids = ids
        if instances and not isinstance(instances, list):
            raise TypeError("Expected argument 'instances' to be a list")
        __self__.instances = instances
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        __self__.output_file = output_file
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        __self__.tags = tags
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        id is the provider-assigned unique ID for this managed resource.
        """
class AwaitableGetDBAuditInstanceResult(GetDBAuditInstanceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDBAuditInstanceResult(
            description_regex=self.description_regex,
            descriptions=self.descriptions,
            ids=self.ids,
            instances=self.instances,
            output_file=self.output_file,
            tags=self.tags,
            id=self.id)

def get_db_audit_instance(description_regex=None,ids=None,output_file=None,tags=None,opts=None):
    """
    Use this data source to access information about an existing resource.
    
    """
    __args__ = dict()

    __args__['descriptionRegex'] = description_regex
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['tags'] = tags
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('alicloud:yundun/getDBAuditInstance:getDBAuditInstance', __args__, opts=opts).value

    return AwaitableGetDBAuditInstanceResult(
        description_regex=__ret__.get('descriptionRegex'),
        descriptions=__ret__.get('descriptions'),
        ids=__ret__.get('ids'),
        instances=__ret__.get('instances'),
        output_file=__ret__.get('outputFile'),
        tags=__ret__.get('tags'),
        id=__ret__.get('id'))
