# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetQueuesResult:
    """
    A collection of values returned by getQueues.
    """
    def __init__(__self__, name_prefix=None, names=None, output_file=None, queues=None, id=None):
        if name_prefix and not isinstance(name_prefix, str):
            raise TypeError("Expected argument 'name_prefix' to be a str")
        __self__.name_prefix = name_prefix
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        __self__.names = names
        """
        A list of queue names. 
        """
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        __self__.output_file = output_file
        if queues and not isinstance(queues, list):
            raise TypeError("Expected argument 'queues' to be a list")
        __self__.queues = queues
        """
        A list of queues. Each element contains the following attributes:
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        id is the provider-assigned unique ID for this managed resource.
        """
class AwaitableGetQueuesResult(GetQueuesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetQueuesResult(
            name_prefix=self.name_prefix,
            names=self.names,
            output_file=self.output_file,
            queues=self.queues,
            id=self.id)

def get_queues(name_prefix=None,output_file=None,opts=None):
    """
    This data source provides a list of MNS queues in an Alibaba Cloud account according to the specified parameters.
    
    :param str name_prefix: A string to filter resulting queues by their name prefixs.

    > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/d/mns_queues.html.markdown.
    """
    __args__ = dict()

    __args__['namePrefix'] = name_prefix
    __args__['outputFile'] = output_file
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('alicloud:mns/getQueues:getQueues', __args__, opts=opts).value

    return AwaitableGetQueuesResult(
        name_prefix=__ret__.get('namePrefix'),
        names=__ret__.get('names'),
        output_file=__ret__.get('outputFile'),
        queues=__ret__.get('queues'),
        id=__ret__.get('id'))
