# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class MachineGroup(pulumi.CustomResource):
    identify_lists: pulumi.Output[list]
    """
    The machine identification.
    """
    identify_type: pulumi.Output[str]
    """
    The machine identification type, including IP and user-defined identity. Valid values are "ip" and "userdefined". Default to "ip".
    * `identify_list`- (Required) The specific machine identification, which can be an IP address or user-defined identity.
    """
    name: pulumi.Output[str]
    """
    The machine group name, which is unique in the same project.
    """
    project: pulumi.Output[str]
    """
    The project name to the machine group belongs.
    """
    topic: pulumi.Output[str]
    """
    The topic of a machine group.
    """
    def __init__(__self__, resource_name, opts=None, identify_lists=None, identify_type=None, name=None, project=None, topic=None, __props__=None, __name__=None, __opts__=None):
        """
        Create a MachineGroup resource with the given unique name, props, and options.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] identify_lists: The machine identification.
        :param pulumi.Input[str] identify_type: The machine identification type, including IP and user-defined identity. Valid values are "ip" and "userdefined". Default to "ip".
               * `identify_list`- (Required) The specific machine identification, which can be an IP address or user-defined identity.
        :param pulumi.Input[str] name: The machine group name, which is unique in the same project.
        :param pulumi.Input[str] project: The project name to the machine group belongs.
        :param pulumi.Input[str] topic: The topic of a machine group.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/r/log_machine_group.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if identify_lists is None:
                raise TypeError("Missing required property 'identify_lists'")
            __props__['identify_lists'] = identify_lists
            __props__['identify_type'] = identify_type
            __props__['name'] = name
            if project is None:
                raise TypeError("Missing required property 'project'")
            __props__['project'] = project
            __props__['topic'] = topic
        super(MachineGroup, __self__).__init__(
            'alicloud:log/machineGroup:MachineGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, identify_lists=None, identify_type=None, name=None, project=None, topic=None):
        """
        Get an existing MachineGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] identify_lists: The machine identification.
        :param pulumi.Input[str] identify_type: The machine identification type, including IP and user-defined identity. Valid values are "ip" and "userdefined". Default to "ip".
               * `identify_list`- (Required) The specific machine identification, which can be an IP address or user-defined identity.
        :param pulumi.Input[str] name: The machine group name, which is unique in the same project.
        :param pulumi.Input[str] project: The project name to the machine group belongs.
        :param pulumi.Input[str] topic: The topic of a machine group.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/r/log_machine_group.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["identify_lists"] = identify_lists
        __props__["identify_type"] = identify_type
        __props__["name"] = name
        __props__["project"] = project
        __props__["topic"] = topic
        return MachineGroup(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

