# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class ZoneAttachment(pulumi.CustomResource):
    lang: pulumi.Output[str]
    """
    The language of code.
    """
    user_client_ip: pulumi.Output[str]
    """
    The user custom IP address.
    """
    vpc_ids: pulumi.Output[list]
    """
    The id List of the VPC with the same region, for example:["vpc-1","vpc-2"]. 
    """
    vpcs: pulumi.Output[list]
    """
    The List of the VPC:
    
      * `regionId` (`str`) - The region of the vpc. If not set, the current region will instead of.
      * `vpc_id` (`str`) - The Id of the vpc.
    """
    zone_id: pulumi.Output[str]
    """
    The name of the Private Zone Record.
    """
    def __init__(__self__, resource_name, opts=None, lang=None, user_client_ip=None, vpc_ids=None, vpcs=None, zone_id=None, __props__=None, __name__=None, __opts__=None):
        """
        Create a ZoneAttachment resource with the given unique name, props, and options.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] lang: The language of code.
        :param pulumi.Input[str] user_client_ip: The user custom IP address.
        :param pulumi.Input[list] vpc_ids: The id List of the VPC with the same region, for example:["vpc-1","vpc-2"]. 
        :param pulumi.Input[list] vpcs: The List of the VPC:
        :param pulumi.Input[str] zone_id: The name of the Private Zone Record.
        
        The **vpcs** object supports the following:
        
          * `regionId` (`pulumi.Input[str]`) - The region of the vpc. If not set, the current region will instead of.
          * `vpc_id` (`pulumi.Input[str]`) - The Id of the vpc.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/r/pvtz_zone_attachment.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['lang'] = lang
            __props__['user_client_ip'] = user_client_ip
            __props__['vpc_ids'] = vpc_ids
            __props__['vpcs'] = vpcs
            if zone_id is None:
                raise TypeError("Missing required property 'zone_id'")
            __props__['zone_id'] = zone_id
        super(ZoneAttachment, __self__).__init__(
            'alicloud:pvtz/zoneAttachment:ZoneAttachment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, lang=None, user_client_ip=None, vpc_ids=None, vpcs=None, zone_id=None):
        """
        Get an existing ZoneAttachment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] lang: The language of code.
        :param pulumi.Input[str] user_client_ip: The user custom IP address.
        :param pulumi.Input[list] vpc_ids: The id List of the VPC with the same region, for example:["vpc-1","vpc-2"]. 
        :param pulumi.Input[list] vpcs: The List of the VPC:
        :param pulumi.Input[str] zone_id: The name of the Private Zone Record.
        
        The **vpcs** object supports the following:
        
          * `regionId` (`pulumi.Input[str]`) - The region of the vpc. If not set, the current region will instead of.
          * `vpc_id` (`pulumi.Input[str]`) - The Id of the vpc.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/r/pvtz_zone_attachment.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["lang"] = lang
        __props__["user_client_ip"] = user_client_ip
        __props__["vpc_ids"] = vpc_ids
        __props__["vpcs"] = vpcs
        __props__["zone_id"] = zone_id
        return ZoneAttachment(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

